Package: rpart
Priority: recommended
Version: 3.1-32
Date: March 2002 version of rpart, R version 2006-09-26
Author: Terry M Therneau and Beth Atkinson <atkinson@mayo.edu>.
        R port by Brian Ripley <ripley@stats.ox.ac.uk>.
Maintainer: Brian Ripley <ripley@stats.ox.ac.uk>
Description: Recursive partitioning and regression trees
Title: Recursive Partitioning
Depends: R (>= 2.4.0), graphics, stats, grDevices
Suggests: survival
License: use under GPL 2 or later, or see file LICENCE
LazyData: yes
URL: S-PLUS 6.x original at http://mayoresearch.mayo.edu/mayo/research/biostat/splusfunctions.cfm
Packaged: Tue Sep 26 10:20:45 2006; ripley
