# The `rpart` package <img src="man/figures/rpart.png" alt="Rpart logo" style="float:right;height:232.25px" align="right" height="232.25">


[![CRAN_STATUS_BADGE](http://www.r-pkg.org/badges/version/rpart)](https://CRAN.R-project.org/package=rpart)
[![Downloads](http://cranlogs.r-pkg.org/badges/rpart)](https://CRAN.R-project.org/package=rpart)
[![Travis-CI Build Status](https://travis-ci.org/bethatkinson/rpart.svg?branch=master)](https://travis-ci.org/bethatkinson/rpart)


This is the source code for the  `rpart` package, which is a recommended package in R.
It gets posted to the comprehensive R archive (CRAN) as needed after undergoing a thorough testing.


## Overview

The `rpart` code builds classification or regression models of a very
general structure using a two stage procedure; the resulting models can be
represented as binary trees. The package implements many of the ideas found
in the CART (Classification and Regression Trees) book and programs of
Breiman, Friedman, Olshen and Stone.  Because CART is the trademarked name
of a particular software implementation of these ideas and `tree` was used
for the Splus routines of Clark and Pregibon, a different acronym -
Recursive PARTitioning or rpart - was chosen.
